@@ -22,12 +22,15 @@ pub enum GitMitError {
     Io(String, String),
     #[error("failed to generate config with `{0}`: {1}")]
     Exec(String, String),
+    #[cfg(not(target_os = "windows"))]
     #[error("failed to calculate config directory {0}")]
     Xdg(#[from] xdg::BaseDirectoriesError),
     #[error("failed to parse mit author config {0}")]
     AuthorConfigParse(#[from] mit::AuthorConfigParseError),
     #[error("failed to set mit in vcs {0}")]
     AuthorVcs(#[from] mit::VcsError),
+    #[error("appdata environment variable missing {0}")]
+    AppDataMissing(#[from] std::env::VarError),
 }
 
 impl GitMitError {
